# ###############################################
# Data Analysis: Speeches in the German Bundestag
# ###############################################
#
#
# SOP and JBS 2010
# 
# This code contains the functions that will be applied to the legislative terms to
# select for each month backbencher MPs, party leaders, district MPs, list MPs, parties
# and speeches.


#### Function 1: COMPARE LIST AND DISTRICT MP SPEECHES OVER TIME
#### Function does the following for a specific legislative term: 
#### 1. Select backbencher MPs in each month
#### 2. Divide backbencher MPs up according to whether elected in district or from list
#### 3. Calculate number of speeches for each set of MPs as well as the proportion of
#### disrict MP speeches (compared to baseline of actual proportion of district MPs)


listdistrictMPs<-function(legperiod=NA,data=BundestagSpeeches) {




if(is.na(legperiod)==TRUE){
	cat("Please indicate a legislative period (8 through 13)\n")
	stop()
	}
	
# check if two digits indicated for legislative period
if(legperiod<8 || legperiod>13){
	 cat("Warning: Data covers only leg period 8-13. \n")
	 stop()
}

# extract speeches of LP 
if(legperiod==8){
	speeches<-eval(parse(text=paste("data$speeches",0,legperiod,sep="")))
	pattern<-paste("speech",0,legperiod,"WP",sep="")
	}
	
if(legperiod==9){
	speeches<-eval(parse(text=paste("data$speeches",0,legperiod,sep="")))
	pattern<-paste("speech",0,legperiod,sep="")
	}
if (legperiod==10||legperiod==11||legperiod==12|legperiod==13){
	speeches<-eval(parse(text=paste("data$speeches",legperiod,sep="")))
	pattern<-paste("speech",legperiod,sep="")
	}

# extract months, members, leaders 
time<-data$time[data$time$LegislativePeriod==legperiod,]

mpinfo<-data$BTleadership[,c(1:5)]
status<-data$BTleadership[,c(12:279)]
lpstatus<-status[,data$time$LegislativePeriod==legperiod]
	
leaders<-as.data.frame(cbind(mpinfo,lpstatus))

	
members<-data$BTmembership[,c(1:5,15:282)]
members<-as.data.frame(cbind(data$BTmembership[,c(1:5)],members[,data$time$LegislativePeriod==legperiod]))
	
actualmonths<-names(speeches)[2:length(speeches)]
actualmonths<-sub(pattern,"", actualmonths)

	
time$actualmonths<-time[,5]%in%actualmonths

leaders$listdistrict<-eval(parse(text=paste("BundestagSpeeches$BTmembership$listdistrictLP",legperiod,sep="")))

index<-dim(time)[1] 

# create holding matrices for results, i.e. proportion of speeches for each party
listdistrict.res<-as.data.frame(matrix(NA,index,6))
names(listdistrict.res)<-c("District MP speeches","List MP speeches","Prop. of district MP speeches","Prop. of district MP speeches CI lower","Prop. of district MP speeches CI upper","Prop. of district MPs in BT")
rownames(listdistrict.res)<-time$monthyear

# actual number of months for which we have downloaded speeches
monthindicator<-as.numeric(rownames(time)[time$actualmonths==TRUE])
monthindicator<-monthindicator-monthindicator[1]+1
i<-1

# loop over number of actual months and do for each month
for (k in monthindicator ) {	
		
		
		# select backbenchers in this month
		backbenchers<-leaders[leaders[,5+i]==1,]
		backbenchers<-subset(backbenchers,select=c("Lfd. Nr. ","Name (Parlamentarischer Namenszusatz in Klammern) ","Geb.-Datum Verstorben ","Partei /Fraktion/Gruppe (letzter Stand) ","Fraktionswechsel","listdistrict"))
		
		
		# select district and list MPs from backbenchers
		members.district<-backbenchers$"Lfd. Nr. "[backbenchers$listdistrict=="DISTRICT"]
		members.list<-backbenchers$"Lfd. Nr. "[backbenchers$listdistrict=="LIST"]
		
				
		# extract speech counts for these two groups 
		districtMPs.speeches<-speeches[speeches$LaufnrID%in%members.district==TRUE,i+1]
		listMPs.speeches<-speeches[speeches$LaufnrID%in%members.list==TRUE,i+1]
		
		# write number of speeches to output
		listdistrict.res[k,1]<-sum(districtMPs.speeches)
		listdistrict.res[k,2]<-sum(listMPs.speeches)
		
		# calculate proportion of district MP speeches to list MP speeches
		listdistrict.res[k,3]<-sum(districtMPs.speeches)/(sum(districtMPs.speeches)+sum(listMPs.speeches))
		listdistrict.res[k,6]<-length(members.district)/ (length(members.district)+length(members.list))
		
		# generate confidence intervals for proportion via nonparametric bootstrap
		boots<-rep(NA,1000)
		
		for (j in 1:1000) {
		
					boot.districtMPs<-sample(districtMPs.speeches,length(districtMPs.speeches),replace=TRUE)
					boot.listMPs<-sample(listMPs.speeches,length(listMPs.speeches),replace=TRUE)
					boots[j]<-sum(boot.districtMPs) / (sum(boot.listMPs)+sum (boot.districtMPs))
		}
		
		# record lower and upper limit of confidence interval
		if (sum(is.na(boots))==0) 	listdistrict.res[k,4]<-quantile(boots,0.025)
		if (sum(is.na(boots))==0) 	listdistrict.res[k,5]<-quantile(boots,0.975)
	
		# Increase month index by one unit 
		i<-i+1	 
		
		}
		
		return(listdistrict.res)
}


listdistrictGER<-function(legperiod=NA,partysub=FALSE,myparty=NA,data=NA,nounif=FALSE) {
	
	

	if(is.na(legperiod)==TRUE){
		cat("Please indicate a legislative period (8 through 13)\n")
		stop()
	}
	

	
		#cat("You chose legislative period:",legperiod,"\n")	
# extract speeches of LP 
	if(legperiod==8){
		speeches<-eval(parse(text=paste("data$speeches",0,legperiod,sep="")))

	}
	
	if(legperiod==9){
		speeches<-eval(parse(text=paste("data$speeches",0,legperiod,sep="")))
		
	}
	
	if(legperiod=="9a"){
		data$time[49:71,4]<-"9a"
		speeches<-eval(parse(text=paste("data$speeches",0,9,sep="")))
		speeches<-speeches[,c(1,2:20)] # period prior to no confidence vote
	
	}
	if(legperiod=="9b"){
		data$time[73:77,4]<-"9b"
		speeches<-eval(parse(text=paste("data$speeches",0,9,sep="")))
		speeches<-speeches[,c(1,22:24)] # period afer no confidence vote

		
	}
	
	if (legperiod==11){
		speeches<-eval(parse(text=paste("data$speeches",legperiod,sep="")))
		pattern<-paste("speech",legperiod,sep="")
		### Exclude months in which DDR Parliament joined Bundestag (end of 1990) 
		### with nounif=TRUE (no unification)
		if(nounif==TRUE){speeches<-speeches[,1:38]}
	}
	if (legperiod==10||legperiod==12|legperiod==13){
		speeches<-eval(parse(text=paste("data$speeches",legperiod,sep="")))
		pattern<-paste("speech",legperiod,sep="")
		
	}
	
# extract months, members, leaders 
	
	time<-data$time[data$time$LegislativePeriod==legperiod,]
	if(nounif==TRUE){time<-time[1:44,]}
	
	mpinfo<-data$BTleadership[,c(1:5)]
	status<-data$BTleadership[,c(12:279)]
	lpstatus<-status[,data$time$LegislativePeriod==legperiod]
	if(nounif==TRUE){lpstatus<-lpstatus[,1:44]}
	
	
	
	leaders<-as.data.frame(cbind(mpinfo,lpstatus))
	
	 # create holding matrices for results, i.e. proportion of speeches for each party
listdistrict.res<-as.data.frame(matrix(NA,1,9))
names(listdistrict.res)<-c("District MP speeches","List MP speeches","Prop. of district MP speeches","Prop. of district MP speeches CI lower","Prop. of district MP speeches CI upper","Prop. of district MPs in BT","District MPs","List MPs","Proportion of backbenchers (out of all MPs)")
rownames(listdistrict.res)<-legperiod

	
	
	
	###### NEW: MPs switch positions in each legislative term
	###### To aggregate on the legislative term, we use the position
	###### held by each MP for the majority of months in that term
	
	leaders$numberofpositions<-as.numeric(lapply(apply(lpstatus,1,unique),length))
	leaders$termleadershipstatus<-apply(lpstatus,1,mean)
	
	
	if(legperiod=="9a"){legperiod<-9}
	if(legperiod=="9b"){legperiod<-9}
	
	leaders$listdistrict<-eval(parse(text=paste("data$BTmembership$listdistrictLP",legperiod,sep="")))
	
	

	#cat("Total MPs in Legislative Term:",nrow(leaders[leaders$termleadershipstatus>0,]),"\n")
	
	
#### SUBSET PARTY MEMBERS 
	if (partysub==TRUE){
		#backbenchers<-subset(backbenchers,backbenchers[,4]%in%myparty)
		#partyleaders <-subset(partyleaders, partyleaders[,4]%in%myparty)
		
		leaders<-subset(leaders, leaders[,4]%in%myparty)
		leaders<-leaders[leaders$termleadershipstatus>0,]
		#cat(paste("You are subsetting:",myparty),"\n")
			
		}	
	

	
	partysize<-nrow(leaders)
	
	#cat("Total Party MPs:", partysize,"\n")
	#cat("Total backbencher MPs:", nrow(leaders[leaders$termleadershipstatus==1,]),"\n")
	
# select backbenchers
		backbenchers<-leaders[leaders$termleadershipstatus==1,]
		backbenchers<-subset(backbenchers,select=c("Lfd. Nr. ","Name (Parlamentarischer Namenszusatz in Klammern) ","Geb.-Datum Verstorben ","Partei /Fraktion/Gruppe (letzter Stand) ","Fraktionswechsel","listdistrict"))
		

	

		# select district and list MPs from backbenchers
		members.district<-backbenchers$"Lfd. Nr. "[backbenchers$listdistrict=="DISTRICT"]
		members.list<-backbenchers$"Lfd. Nr. "[backbenchers$listdistrict=="LIST"]
		
				
					
		# extract speech counts for these two groups 
		districtMPs.speeches <-rowSums(speeches[speeches$LaufnrID%in%members.district==TRUE,2:ncol(speeches)])
		
		listMPs.speeches<-rowSums(speeches[speeches$LaufnrID%in%members.list==TRUE,2:ncol(speeches)])
		  
	  	
	if(legperiod==8){rownames(listdistrict.res)<-"08"}
	if(legperiod==9){rownames(listdistrict.res)<-"09"}
		
		#listdistrict.res[1,9]<-selectedpartysize/partysize
	   listdistrict.res[1,7]<-length(members.district)
	   listdistrict.res[1,8]<-length(members.list)
		
		
		
		# write number of speeches to output
		listdistrict.res[1,1]<-sum(districtMPs.speeches)
		listdistrict.res[1,2]<-sum(listMPs.speeches)
		
		
		# calculate proportion of district MP speeches to list MP speeches
		listdistrict.res[1,3]<-sum(districtMPs.speeches)/(sum(districtMPs.speeches)+sum(listMPs.speeches))
		listdistrict.res[1,6]<-length(members.district)/ (length(members.district)+length(members.list))

			
		# generate confidence intervals for proportion via nonparametric bootstrap
		boots<-rep(NA,1000)
		
		for (j in 1:1000) {
		
					boot.districtMPs<-sample(districtMPs.speeches,length(districtMPs.speeches),replace=TRUE)
					boot.listMPs<-sample(listMPs.speeches,length(listMPs.speeches),replace=TRUE)
					boots[j]<-sum(boot.districtMPs) / (sum(boot.listMPs)+sum (boot.districtMPs))
		}
		
		# record lower and upper limit of confidence interval
		if (sum(is.na(boots))==0) 	listdistrict.res[1,4]<-quantile(boots,0.025)
		if (sum(is.na(boots))==0) 	listdistrict.res[1,5]<-quantile(boots,0.975)
	
	
		
		return(listdistrict.res)
		
}



leaderproportions<-function(legperiod=NA,leadpositions=NA,partysub=FALSE,myparty=NA,data=BundestagSpeeches) {
	



		if(1%in%leadpositions==TRUE){
		cat("Backbenchers cannot be excluded (category 1)!\n")
		stop()
	}


	
	if(is.na(legperiod)==TRUE){
		cat("Please indicate a legislative period (8 through 13)\n")
		stop()
	}
	
# check if two digits indicated for legislative period
	if(legperiod<8 || legperiod>13){
		cat("Warning: Data covers only leg period 8-13. \n")
		stop()
	}
	
	
	
# extract speeches of LP 
	if(legperiod==8){
		speeches<-eval(parse(text=paste("data$speeches",0,legperiod,sep="")))
		pattern<-paste("speech",0,legperiod,"WP",sep="")
		cat("You chose legislative period smaller than 10\n")
	}
	
	if(legperiod==9){
		speeches<-eval(parse(text=paste("data$speeches",0,legperiod,sep="")))
		pattern<-paste("speech",0,legperiod,sep="")
		cat("You chose legislative period smaller than 10\n")
	}
	if (legperiod==10||legperiod==11||legperiod==12|legperiod==13){
		speeches<-eval(parse(text=paste("data$speeches",legperiod,sep="")))
		pattern<-paste("speech",legperiod,sep="")
		cat("You chose legislative period 10 or above\n")
	}
	
# extract months, members, leaders 
	time<-data$time[data$time$LegislativePeriod==legperiod,]
	
	mpinfo<-data$BTleadership[,c(1:5)]
	status<-data$BTleadership[,c(12:279)]
	lpstatus<-status[,data$time$LegislativePeriod==legperiod]
	
	leaders<-as.data.frame(cbind(mpinfo,lpstatus))
	
	
	members<-data$BTmembership[,c(1:5,15:282)]
	members<-as.data.frame(cbind(data$BTmembership[,c(1:5)],members[,data$time$LegislativePeriod==legperiod]))
	
	actualmonths<-names(speeches)[2:length(speeches)]
	actualmonths<-sub(pattern,"", actualmonths)
	
	
	time$actualmonths<-time[,5]%in%actualmonths
	
	leaders$listdistrict<-eval(parse(text=paste("BundestagSpeeches$BTmembership$listdistrictLP",legperiod,sep="")))
	
	
	index<-dim(time)[1] 
	
# create holding matrices for results, i.e. proportion of speeches for each party
	leader.res<-as.data.frame(matrix(NA,index,6))
	names(leader.res)<-c("Leader speeches","Backbencher speeches","Prop. of leader MP speeches","Prop. of leader MP speeches CI lower","Prop. of leader MP speeches CI upper","Prop. of leader MPs in BT")
	rownames(leader.res)<-time$monthyear
	
# actual number of months for which we have downloaded speeches
	monthindicator<-as.numeric(rownames(time)[time$actualmonths==TRUE])
	monthindicator<-monthindicator-monthindicator[1]+1
	i<-1
	
# loop over number of actual months and do for each month
	for (k in monthindicator ) {	
		
		
# select backbenchers in this month
		backbenchers<-leaders[leaders[,5+i]==1,]
		backbenchers<-subset(backbenchers,select=c("Lfd. Nr. ","Name (Parlamentarischer Namenszusatz in Klammern) ","Geb.-Datum Verstorben ","Partei /Fraktion/Gruppe (letzter Stand) ","Fraktionswechsel","listdistrict"))
		
		
		
		partyleaders<-leaders[leaders[,5+i]%in%leadpositions==TRUE,]
	#	SIMPLY CONSIDER ALL LEADERS: 
	#	partyleaders<-leaders[leaders[,5+i]>1,]
		partyleaders<-subset(partyleaders,select=c("Lfd. Nr. ","Name (Parlamentarischer Namenszusatz in Klammern) ","Geb.-Datum Verstorben ","Partei /Fraktion/Gruppe (letzter Stand) ","Fraktionswechsel","listdistrict"))
		
	
	#### SUBSET PARTY MEMBERS
	if (partysub==TRUE){
		backbenchers<-subset(backbenchers,backbenchers[,4]%in%myparty)
		partyleaders <-subset(partyleaders, partyleaders[,4]%in%myparty)
		cat(paste("You are subsetting:",myparty),"\n")
		cat(paste("Number of backbenchers:"),nrow(backbenchers),"\n")
		cat(paste("Number of leaders:"),nrow(partyleaders),"\n")
		}	
		
# extract speech counts for these two groups 
		leader.speeches<-speeches[speeches$LaufnrID%in%partyleaders$"Lfd. Nr. "==TRUE,i+1]
		backbencher.speeches<-speeches[speeches$LaufnrID%in%backbenchers$"Lfd. Nr. "==TRUE,i+1]
		
# write number of speeches to output
		leader.res[k,1]<-sum(leader.speeches)
		leader.res[k,2]<-sum(backbencher.speeches)
		
# calculate proportion of district MP speeches to list MP speeches
		leader.res[k,3]<-sum(leader.speeches)/(sum(backbencher.speeches)+sum(leader.speeches))
		leader.res[k,6]<-nrow(partyleaders)/ (nrow(backbenchers)+nrow(partyleaders))
		
# generate confidence intervals for proportion via nonparametric bootstrap
		boots<-rep(NA,1000)
		
		for (j in 1:1000) {
			
			boot.leaders<-sample(leader.speeches,length(leader.speeches),replace=TRUE)
			boot.backbenchers<-sample(backbencher.speeches,length(backbencher.speeches),replace=TRUE)
			boots[j]<-sum(boot.leaders) / (sum(boot.backbenchers)+sum (boot.leaders))
		}
		
# record lower and upper limit of confidence interval
		if (sum(is.na(boots))==0) 	leader.res[k,4]<-quantile(boots,0.025)
		if (sum(is.na(boots))==0) 	leader.res[k,5]<-quantile(boots,0.975)
		
		
# Increase month index by one unit 
		i<-i+1	 
		
	}
	
	return(leader.res)
}




leaderproportionsGER<-function(legperiod=NA,leadpositions=NA,partysub=FALSE,myparty=NA,data=NA,nounif=FALSE) {
	
	if(1%in%leadpositions==TRUE){
		cat("Backbenchers cannot be excluded (category 1)!\n")
		stop()
	}

	if(is.na(legperiod)==TRUE){
		cat("Please indicate a legislative period (8 through 13)\n")
		stop()
	}
	

	
		#cat("You chose legislative period:",legperiod,"\n")	
# extract speeches of LP 
	if(legperiod==8){
		speeches<-eval(parse(text=paste("data$speeches",0,legperiod,sep="")))

	}
	
	if(legperiod==9){
		speeches<-eval(parse(text=paste("data$speeches",0,legperiod,sep="")))
		
	}
	
	if(legperiod=="9a"){
		data$time[49:71,4]<-"9a"
		speeches<-eval(parse(text=paste("data$speeches",0,9,sep="")))
		speeches<-speeches[,c(1,2:20)] # period prior to no confidence vote
	
	}
	if(legperiod=="9b"){
		data$time[73:77,4]<-"9b"
		speeches<-eval(parse(text=paste("data$speeches",0,9,sep="")))
		speeches<-speeches[,c(1,22:24)] # period afer no confidence vote

		
	}
	
	if (legperiod==11){
		speeches<-eval(parse(text=paste("data$speeches",legperiod,sep="")))
		pattern<-paste("speech",legperiod,sep="")
		### Exclude months in which DDR Parliament joined Bundestag (end of 1990) 
		### with nounif=TRUE (no unification)
		if(nounif==TRUE){speeches<-speeches[,1:38]}
	}
	if (legperiod==10||legperiod==12|legperiod==13){
		speeches<-eval(parse(text=paste("data$speeches",legperiod,sep="")))
		pattern<-paste("speech",legperiod,sep="")
		
	}
	
# extract months, members, leaders 
	
	time<-data$time[data$time$LegislativePeriod==legperiod,]
	if(nounif==TRUE){time<-time[1:44,]}
	
	mpinfo<-data$BTleadership[,c(1:5)]
	status<-data$BTleadership[,c(12:279)]
	lpstatus<-status[,data$time$LegislativePeriod==legperiod]
	if(nounif==TRUE){lpstatus<-lpstatus[,1:44]}
	
	

	###### recode desired leader positions to a dummy
	for (j in 1:length(leadpositions)){
	lpstatus<-replace(lpstatus, lpstatus==leadpositions[j], 100)
	}
	
	
	leaders<-as.data.frame(cbind(mpinfo,lpstatus))
	
	 # create holding matrices for results, i.e. proportion of speeches for each party
	leader.res<-as.data.frame(matrix(NA,1,9))
	names(leader.res)<-c("Leader speeches","Backbencher speeches","Prop. of leader MP speeches","Prop. of leader MP speeches CI lower","Prop. of leader MP speeches CI upper","Prop. of leader MPs in BT","Leaders","Backbenchers","Proportion of party MPs considered")
	rownames(leader.res)<-legperiod

	
	
	###### MPs switch positions in each legislative term
	###### To aggregate on the legislative term, we use the position
	###### held by each MP for the majority of months in that term
	
	leaders$numberofpositions<-as.numeric(lapply(apply(lpstatus,1,unique),length))
	leaders$termleadershipstatus<-apply(lpstatus,1,mean)
	
	
	if(legperiod=="9a"){legperiod<-9}
	if(legperiod=="9b"){legperiod<-9}
	
	leaders$listdistrict<-eval(parse(text=paste("data$BTmembership$listdistrictLP",legperiod,sep="")))
	
	

	#cat("Total MPs in Legislative Term:",nrow(leaders[leaders$termleadershipstatus>0,]),"\n")
	
	
#### SUBSET PARTY MEMBERS 
	if (partysub==TRUE){
		#backbenchers<-subset(backbenchers,backbenchers[,4]%in%myparty)
		#partyleaders <-subset(partyleaders, partyleaders[,4]%in%myparty)
		
		leaders<-subset(leaders, leaders[,4]%in%myparty)
		leaders<-leaders[leaders$termleadershipstatus>0,]
		#cat(paste("You are subsetting:",myparty),"\n")
			
		}	
	

	
	#print(round(table(leaders$termleadershipstatus)),digits=2)
	
	partysize<-nrow(leaders)
	
	#cat("Total Party MPs (even partial backbenchers):", partysize,"\n")
	#cat("Total Party MPs with some leader function:", nrow(leaders[leaders$termleadershipstatus>1,]),"\n")
	
# select backbenchers
		backbenchers<-leaders[leaders$termleadershipstatus==1,]
		backbenchers<-subset(backbenchers,select=c("Lfd. Nr. ","Name (Parlamentarischer Namenszusatz in Klammern) ","Geb.-Datum Verstorben ","Partei /Fraktion/Gruppe (letzter Stand) ","Fraktionswechsel","listdistrict"))
		
# select party leaders		
	partyleaders <-leaders[leaders$termleadershipstatus==100,]
	partyleaders<-subset(partyleaders,select=c("Lfd. Nr. ","Name (Parlamentarischer Namenszusatz in Klammern) ","Geb.-Datum Verstorben ","Partei /Fraktion/Gruppe (letzter Stand) ","Fraktionswechsel","listdistrict"))
		
		selectedpartysize<-nrow(backbenchers)+nrow(partyleaders)
		
		#cat(paste("Total selected Party MPs:"),selectedpartysize,"\n")
	   #cat(paste("Number of selected backbenchers:"),nrow(backbenchers),"\n")
		#cat(paste("Number of selected leaders:"),nrow(partyleaders),"\n")

		
# extract speech counts for these two groups 
		leader.speeches<-rowSums(speeches[speeches$LaufnrID%in%partyleaders$"Lfd. Nr. "==TRUE,2:ncol(speeches)])
		backbencher.speeches<-rowSums(speeches[speeches$LaufnrID%in%backbenchers$"Lfd. Nr. "==TRUE,2:ncol(speeches)])
		
	   
	   
	  	
	if(legperiod==8){rownames(leader.res)<-"08"}
	if(legperiod==9){rownames(leader.res)<-"09"}
		
		leader.res[1,9]<-selectedpartysize/partysize
	   leader.res[1,7]<-nrow(partyleaders)
	   leader.res[1,8]<-nrow(backbenchers)
		leader.res[1,1]<-sum(leader.speeches)
		leader.res[1,2]<-sum(backbencher.speeches)
		
# calculate proportion of district MP speeches to list MP speeches
		leader.res[1,3]<-sum(leader.speeches)/(sum(backbencher.speeches)+sum(leader.speeches))
		leader.res[1,6]<-nrow(partyleaders)/ (nrow(backbenchers)+nrow(partyleaders))
		
# generate confidence intervals for proportion via nonparametric bootstrap
		boots<-rep(NA,1000)
		
		for (j in 1:1000) {
			
			boot.leaders<-sample(leader.speeches,length(leader.speeches),replace=TRUE)
			boot.backbenchers<-sample(backbencher.speeches,length(backbencher.speeches),replace=TRUE)
			boots[j]<-sum(boot.leaders) / (sum(boot.backbenchers)+sum (boot.leaders))
		}
		
# record lower and upper limit of confidence interval
		if (sum(is.na(boots))==0) 	leader.res[1,4]<-quantile(boots,0.025)
		if (sum(is.na(boots))==0) 	leader.res[1,5]<-quantile(boots,0.975)
		
		
	
	return(leader.res)
}







plot.listdistrict<-function(data=NA,plotleg=TRUE,legendpos=c(25,0.95),mytitle=NA){
cat("Plotting district MP speech proportions...\nNote: Months for which bootstrapped CIs could not be calculated are dropped.\nIn addition, months with less than 10 speeches are dropped.\n\n")

data[is.na(data[,4])==TRUE,3]<-NA

cat("Removing the following months because speech counts are less than 10:\n")
for (i in 1:nrow(data)){
if(data[i,1]+data[i,2]<10|is.na(data[i,1])){
		data[i,3:5]<-NA
		print(rownames(data[i,]))
	}
}


plot(1:dim(data)[1], data[,3],type="n",ylim=c(0,1),xaxt="n",main=mytitle,ylab="Proportion of speeches",xlab="Months in Legislative Period")
#axis(1,at=1:dim(data)[1],labels=rownames(data),cex=0.9)
axis(1,at=1:dim(data)[1],labels=FALSE,cex=0.9)

text(1:dim(data)[1], par("usr")[3]-0.025, labels = rownames(data), srt = 45, adj = c(1.1,1.1), xpd = TRUE, cex=.8)

lines(1:dim(data)[1], data[,3],lwd=2)
lines(1:dim(data)[1], data[,4],lty="dashed",lwd=1)
lines(1:dim(data)[1], data[,5],lty="dashed",lwd=1)
lines(1:dim(data)[1], data[,6],lty="dotted",lwd=3,col="red")

if(plotleg==TRUE){legend(legendpos[1],legendpos[2],c("Proportion of SMD MP speeches","Proportion of SMD MPs"),lty=c("solid","dotted"),lwd=c(1,2))}


}


plot.leader<-function(data=NA,plotleg=TRUE,legendpos=c(25,0.95),mytitle=NA){
cat("Plotting leader MP speech proportions...\nNote: Months for which bootstrapped CIs could not be calculated are dropped.\nIn addition, months with less than 10 speeches are dropped.\n\n")

data[is.na(data[,4])==TRUE,3]<-NA

cat("Removing the following months because speech counts are less than 10:\n")
for (i in 1:nrow(data)){
if(data[i,1]+data[i,2]<10|is.na(data[i,1])){
		data[i,3:5]<-NA
		print(rownames(data[i,]))
	}
}



plot(1:dim(data)[1], data[,3],type="n",ylim=c(0,1),xaxt="n",main=mytitle,ylab="Proportion of speeches",xlab="Months in Legislative Period")
#axis(1,at=1:dim(data)[1],labels=rownames(data),cex=0.9)
axis(1,at=1:dim(data)[1],labels=FALSE,cex=0.9)

text(1:dim(data)[1], par("usr")[3]-0.025, labels = rownames(data), srt = 45, adj = c(1.1,1.1), xpd = TRUE, cex=.8)


lines(1:dim(data)[1], data[,3],lwd=2)
lines(1:dim(data)[1], data[,4],lty="dashed",lwd=1)
lines(1:dim(data)[1], data[,5],lty="dashed",lwd=1)
lines(1:dim(data)[1], data[,6],lty="dotted",lwd=3,col="red")
if(plotleg==TRUE){legend(legendpos[1],legendpos[2],c("Proportion of Party Leader MP speeches","Proportion of Party Leader MPs"),lty=c("solid","dotted"),lwd=c(1,2))}


}




plotleadertermGER<-function(data=NA,plotleg=TRUE,legendpos=c(25,0.95),mytitle=NA,xlabtitle=NA){
#cat("Plotting leader MP speech proportions...\nNote: Months for which bootstrapped CIs could not be calculated are dropped.\nIn addition, months with less than 10 speeches are dropped.\n\n")

data<-data[rev(order(rownames(data))),]


par(mar=c(4,7,3,2))

plot(c(0,1),c(0.5,dim(data)[1]+0.5),type="n",xlim=c(0,1),xaxt="n",yaxt="n",main=mytitle,xlab="",ylab="")


rownames(data)[rownames(data)=="08"]<-"1976-1980"
rownames(data)[rownames(data)=="09"]<-"1980-1983"
rownames(data)[rownames(data)=="10"]<-"1983-1987"
rownames(data)[rownames(data)=="11"]<-"1987-1990"
rownames(data)[rownames(data)=="12"]<-"1990-1994"
rownames(data)[rownames(data)=="13"]<-"1994-1998"
axis(2,at=1:dim(data)[1],labels=rownames(data),cex.axis=1,las=1)
axis(1,at=seq(0,1,by=0.1),labels=TRUE,cex.axis=1)

mtext("Legislative Term",2,line=5.5,cex=1)
mtext(xlabtitle,1,line=2.5,cex=1)

segments(0,1:dim(data)[1],1,1:dim(data)[1],lty="dotted",col="gray25")#draw lines
segments(data[,4],1:dim(data)[1],data[,5],1:dim(data)[1],lwd=2)
segments(data[,4],1:dim(data)[1]-0.1,data[,4],1:dim(data)[1]+0.1,lwd=2)
segments(data[,5],1:dim(data)[1]-0.1,data[,5],1:dim(data)[1]+0.1,lwd=2)

segments(data[,6],1:dim(data)[1]-0.45,data[,6],1:dim(data)[1]+0.45,lty="dashed",col="red4",lwd=2)


for (k in 1:dim(data)[1]){
	if (data[k,4]>data[k,6]||data[k,5]<data[k,6]){
	points(data[k,3],k,pch=19,cex=1.5)}
	else{points(data[k,3],k,pch=21,cex=1.5,bg="gray")}
	
#	text(0.65,k+0.25,paste("Leader speeches: ",data[k,1]," (n=",data[k,7],")",sep=""),cex=0.6,adj=c(0,0))
#	text(0.65,k+0.1,paste("Backbencher speeches: ",data[k,2]," (n=",data[k,8],")",sep=""),cex=0.6,adj=c(0,0))
# activate here to plot coverage rate of MPs:	text(0.82,k+0.1,paste("MP coverage rate: ",round(data[k,9],2),sep=""),cex=0.6,adj=c(0,0))
	}



if(plotleg==TRUE){legend(legendpos[1],legendpos[2],c("Proportion of Party Leader MP speeches","Proportion of Party Leader MPs"),lty=c("solid","dotted"),lwd=c(1,2))}


}